isInPip property
true while the app is actually shrunk into the system PiP window.
UTDLiveRoom swaps its body to the compact PiP view while this is true.
Implementation
final ValueNotifier<bool> isInPip = ValueNotifier(false);
true while the app is actually shrunk into the system PiP window.
UTDLiveRoom swaps its body to the compact PiP view while this is true.
final ValueNotifier<bool> isInPip = ValueNotifier(false);