UTDReconnectionHandler class
Constructors
-
UTDReconnectionHandler({required Future<
void> onLightSync(), required Future<void> onFullSync(), required VoidCallback onForceExit})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onForceExit → VoidCallback
-
final
-
onFullSync
→ Future<
void> Function() -
final
-
onLightSync
→ Future<
void> Function() -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDisconnected(
) → void -
onReconnected(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited