UTDRoleListPage class
One page of the paginated list-by-role response.
Constructors
-
UTDRoleListPage({required List<
UTDRoleUser> data, required int page, required int perPage, required int total, required int totalPages}) -
const
-
UTDRoleListPage.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
data
→ List<
UTDRoleUser> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int
-
final
- perPage → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
final
- totalPages → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited