UTDRoleUser class

A single participant row from GET .../participants/by-role.

Constructors

UTDRoleUser({required String identity, String? name, String? role, UTDRoleUserAttributes? attributes})
const
UTDRoleUser.fromJson(Map<String, dynamic> json)
factory

Properties

attributes UTDRoleUserAttributes?
final
hashCode int
The hash code for this object.
no setterinherited
identity String
final
name String?
final
role String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited