UTDBanUserAttributes class
Attributes snapshotted for a banned user (mirrors the participant attributes
the client set: fr, frt, avatar, cn). All fields are optional —
the whole object is null when the user was offline at ban time.
Constructors
- UTDBanUserAttributes({String? fr, String? frt, String? avatar, String? cn})
-
const
-
UTDBanUserAttributes.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited