UTDRoleChangeEvent class
The realtime _role_change data message, broadcast to ALL participants
whenever a role changes.
⚠️ This message is sent from the server API, so in the media engine
DataReceivedEvent the participant field is null. Identify the affected
user from identity, never from the event sender.
Constructors
- UTDRoleChangeEvent({required String identity, required String role, String? previousRole})
-
const
-
UTDRoleChangeEvent.fromData(Map<
String, dynamic> data) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → String
-
final
- previousRole → String?
-
final
- role → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited